@@ -2,8 +2,8 @@
 // Copyright (c) 2012-2022, Oslandia.
 // SPDX-License-Identifier: LGPL-2.0-or-later
 
-#ifndef _SFCGAL_ALGORITHM_OFFSET_H_
-#define _SFCGAL_ALGORITHM_OFFSET_H_
+#ifndef SFCGAL_ALGORITHM_OFFSET_H_
+#define SFCGAL_ALGORITHM_OFFSET_H_
 
 #include "SFCGAL/config.h"
 
@@ -23,7 +23,6 @@ struct NoValidityCheck;
  *
  * @warning test in order to compare with minkowski sum
  * @pre g is a valid Geometry
- * @ingroup public_api
  */
 SFCGAL_API std::unique_ptr<MultiPolygon>
            offset(const Geometry &g, const double &r);
@@ -33,7 +32,6 @@ SFCGAL_API std::unique_ptr<MultiPolygon>
  *
  * @warning test in order to compare with minkowski sum
  * @pre g is a valid Geometry
- * @ingroup detail
  * @warning No actual validity check is done.
  */
 SFCGAL_API std::unique_ptr<MultiPolygon>
